@@ -374,7 +374,7 @@ type_name##_get_type (void) \
         (GInstanceInitFunc) type_name##_init, \
         NULL    /* value_table */ \
       }; \
-      g_define_type_id = g_type_register_static (TYPE_PARENT, #TypeName, &g_define_type_info, (GTypeFlags) flags); \
+      g_define_type_id = g_type_register_static (TYPE_PARENT, g_intern_static_string (#TypeName), &g_define_type_info, (GTypeFlags) flags); \
       { CODE ; } \
     } \
   return g_define_type_id; \
