@@ -46,6 +46,7 @@ G_GNUC_EXTENSION typedef signed long long gint64;
 G_GNUC_EXTENSION typedef unsigned long long guint64;
 
 #define G_GINT64_CONSTANT(val)	(G_GNUC_EXTENSION (val##LL))
+#define G_GUINT64_CONSTANT(val)	(G_GNUC_EXTENSION (val##ULL))
 #define G_GINT64_MODIFIER "ll"
 #define G_GINT64_FORMAT "lli"
 #define G_GUINT64_FORMAT "llu"
@@ -77,13 +78,12 @@ typedef unsigned long gsize;
 #define g_memmove(dest,src,len) G_STMT_START { memmove ((dest), (src), (len)); } G_STMT_END
 
 #define GLIB_MAJOR_VERSION 2
-#define GLIB_MINOR_VERSION 8
-#define GLIB_MICRO_VERSION 4
+#define GLIB_MINOR_VERSION 10
+#define GLIB_MICRO_VERSION 3
 
 #define G_OS_UNIX
 
 #define G_VA_COPY	va_copy
-#define G_VA_COPY_AS_ARRAY 1
 
 #ifdef	__cplusplus
 #define	G_HAVE_INLINE	1
@@ -102,9 +102,6 @@ typedef unsigned long gsize;
 #ifndef __cplusplus
 # define G_HAVE_ISO_VARARGS 1
 #endif
-#ifdef __cplusplus
-# define G_HAVE_ISO_VARARGS 1
-#endif
 
 /* gcc-2.95.x supports both gnu style and ISO varargs, but if -ansi
  * is passed ISO vararg support is turned off, and there is no work
@@ -134,7 +131,7 @@ struct _GStaticMutex
 };
 #define	G_STATIC_MUTEX_INIT	{ NULL, { { 0,0,0,0} } }
 #define	g_static_mutex_get_mutex(mutex) \
-  (g_thread_use_default_impl ? ((GMutex*) &((mutex)->static_mutex)) : \
+  (g_thread_use_default_impl ? ((GMutex*) ((mutex)->static_mutex.pad)) : \
    g_static_mutex_get_mutex_impl_shortcut (&((mutex)->runtime_mutex)))
 /* This represents a system thread as used by the implementation. An
  * alien implementaion, as loaded by g_thread_init can only count on
